diff --git a/.gradle/8.2.1/checksums/checksums.lock b/.gradle/8.2.1/checksums/checksums.lock
index 9df0bea..bd7127a 100644
Binary files a/.gradle/8.2.1/checksums/checksums.lock and b/.gradle/8.2.1/checksums/checksums.lock differ
diff --git a/.gradle/8.2.1/fileHashes/fileHashes.lock b/.gradle/8.2.1/fileHashes/fileHashes.lock
index f343359..4e4448c 100644
--- a/.gradle/8.2.1/fileHashes/fileHashes.lock
+++ b/.gradle/8.2.1/fileHashes/fileHashes.lock
@@ -1 +1 @@
-�[�i5���3�
\ No newline at end of file
+�[�i5���Ah
\ No newline at end of file
diff --git a/src/main/java/com/zivilon/cinder_loe/blocks/mordorcobble.java b/src/main/java/com/zivilon/cinder_loe/blocks/mordorcobble.java
new file mode 100644
index 0000000..bd697fd
--- /dev/null
+++ b/src/main/java/com/zivilon/cinder_loe/blocks/mordorcobble.java
@@ -0,0 +1,36 @@
+package com.zivilon.cinder_loe.blocks;
+
+import com.zivilon.cinder_loe.util.Utilities;
+import cpw.mods.fml.relauncher.Side;
+import cpw.mods.fml.relauncher.SideOnly;
+import lotr.common.LOTRCreativeTabs;
+import net.minecraft.block.Block;
+import net.minecraft.block.material.Material;
+import net.minecraft.client.renderer.texture.IIconRegister;
+
+import java.lang.reflect.Field;
+
+public class mordorcobble extends Block {
+    public mordorcobble() {
+        super(Material.rock);
+
+        try {
+            Field tabField = LOTRCreativeTabs.class.getDeclaredField("tabBlock");
+            LOTRCreativeTabs tab = (LOTRCreativeTabs)tabField.get((Object)null);
+            this.setCreativeTab(tab);
+        } catch (IllegalAccessException | NoSuchFieldException var3) {
+            ReflectiveOperationException e = var3;
+            e.printStackTrace();
+        }
+
+        this.setHardness(2.0F);
+        this.setResistance(5.0F);
+        this.setBlockTextureName(Utilities.toSnakeCase("lotr:mordorcobble"));
+        this.setBlockName("lotr:mordorcobble");
+    }
+
+    @SideOnly(Side.CLIENT)
+    public void registerBlockIcons(IIconRegister iconRegister) {
+        this.blockIcon = iconRegister.registerIcon("lotr:mordorcobble");
+    }
+}
diff --git a/src/main/java/com/zivilon/cinder_loe/recipes.java b/src/main/java/com/zivilon/cinder_loe/recipes.java
index b45c057..f1b3f34 100644
--- a/src/main/java/com/zivilon/cinder_loe/recipes.java
+++ b/src/main/java/com/zivilon/cinder_loe/recipes.java
@@ -95,6 +95,7 @@ public class recipes {
 
         GameRegistry.addRecipe(new ShapelessOreRecipe(new ItemStack(CinderLoE.pelmen), Items.wheat, "meat", LOTRMod.salt));
 
+        GameRegistry.addRecipe(new ShapelessOreRecipe(new ItemStack(CinderLoE.mordorcobble), LOTRMod.mordorGravel, LOTRMod.rock, LOTRMod.mordorGravel, LOTRMod.rock));
         GameRegistry.addRecipe((IRecipe)new ShapedOreRecipe(new ItemStack(CinderLoE.cinderBlock), new Object[] { "XXX", "XYX", "XXX",
             Character.valueOf('X'), Blocks.stone, Character.valueOf('Y'), LOTRMod.balrogFire }));
         GameRegistry.addRecipe((IRecipe)new ShapedOreRecipe(new ItemStack(CinderLoE.reedBale), new Object[] { "XXX", "XXX", "XXX",
@@ -107,8 +108,8 @@ public class recipes {
             Character.valueOf('X'), CinderLoE.flour, Character.valueOf('Y'), Items.water_bucket}));
         GameRegistry.addRecipe((IRecipe)new ShapedOreRecipe(new ItemStack(CinderLoE.fishBarrel), new Object[] { "XXX", "XXX", "XXX",
             Character.valueOf('X'), Items.fish}));
-        GameRegistry.addRecipe((IRecipe)new ShapedOreRecipe(new ItemStack(CinderLoE.rustedsword, 8), new Object[] { "X", "y", "y",
-        Character.valueOf('Y'), Items.iron_ingot, Character.valueOf('X'), "stickWood"}));
+        //GameRegistry.addRecipe((IRecipe)new ShapedOreRecipe(new ItemStack(CinderLoE.rustedsword, 8), new Object[] { "X", "y", "y",
+        //Character.valueOf('Y'), Items.iron_ingot, Character.valueOf('X'), "stickWood"}));
         GameRegistry.addRecipe((IRecipe)new ShapedOreRecipe(new ItemStack(CinderLoE.silverChain, 8), new Object[] { "X", "X", "X",
             Character.valueOf('X'), LOTRMod.silver}));
         GameRegistry.addRecipe((IRecipe)new ShapedOreRecipe(new ItemStack(CinderLoE.goldChain, 8), new Object[] { "X", "X", "X",
diff --git a/src/main/resources/assets/lotr/textures/blocks/cinder_block.png.mcmeta b/src/main/resources/assets/lotr/textures/blocks/cinder_block.png.mcmeta
index 7075d08..a3e8d32 100644
--- a/src/main/resources/assets/lotr/textures/blocks/cinder_block.png.mcmeta
+++ b/src/main/resources/assets/lotr/textures/blocks/cinder_block.png.mcmeta
@@ -1,3 +1,3 @@
 {
-  "animation":{"frametime":15}
+  "animation":{"frametime":5}
 }
\ No newline at end of file
diff --git a/src/main/java/com/zivilon/cinder_loe/CinderLoE.java b/src/main/java/com/zivilon/cinder_loe/CinderLoE.java
index 9118591..6bd4dfe 100644
--- a/src/main/java/com/zivilon/cinder_loe/CinderLoE.java
+++ b/src/main/java/com/zivilon/cinder_loe/CinderLoE.java
@@ -74,6 +74,7 @@ import net.minecraftforge.common.MinecraftForge;
 import net.minecraftforge.event.world.WorldEvent;
 
 import static lotr.common.LOTRMod.horseArmorIron;
+import static lotr.common.item.LOTRMaterial.GONDOR;
 import static lotr.common.item.LOTRMaterial.NEAR_HARAD;
 
 import net.minecraft.command.ICommandSender;
@@ -122,7 +123,7 @@ public class CinderLoE {
     public static Block reedBale;
     public static Block dwarvenBrickRuned;
     public static Block fishBarrel;
-    public static Block rustedsword;
+    ///public static Block rustedsword;
     public static Block mistBlock;
     public static Block cutDrystone;
     public static Block cobbleDrystone;
@@ -133,6 +134,7 @@ public class CinderLoE {
     public static Block bronzeChain;
     public static Block plaster;
     public static Block voidblock;
+    public static Block mordorcobble;
     //public static Block verticalWeaponRack;
 
     //Gates
@@ -157,12 +159,11 @@ public class CinderLoE {
     public static Item halva;
     public static Item honey;
 
-    // Misc
+    // Event/special
     public static Item frostblade;
     public static Item daggervoid;
     public static Item spearsolidgold;
     public static Item spearUnnamed;
-    public static Item whip;
     public static Item swordAsh;
     public static Item staffAsh;
     public static Item daggerAsh;
@@ -178,6 +179,12 @@ public class CinderLoE {
     public static Item legsJade;
     public static Item bootsJade;
 
+    // Misc
+
+    // Common tools/weapons
+    public static Item whip;
+    public static Item cleaver;
+
     // Elite Armors
     public static Item helmetserpent;
     public static Item bodyserpent;
@@ -492,6 +499,8 @@ public class CinderLoE {
         GameRegistry.registerBlock(cobbleDrystone, "cobbleDrystone");
         plaster = (new plaster());
         GameRegistry.registerBlock(plaster, "plaster");
+        mordorcobble = (new mordorcobble());
+        GameRegistry.registerBlock(mordorcobble, "mordorcobble");
 
         // Gates
         //gatecharredportcullis = LOTRBlockGate.createWooden(false).setBlockName("lotr:gatecharredportcullis");
@@ -585,7 +594,7 @@ public class CinderLoE {
         * Item Registation, add up the "last ID added" upon adding a new item
         * Weapons will need to be linked
          */
         // Last ID added: 126
 
         // ==Food Items==
         ItemRegistration.registerItem(onion, "onion", 89);
@@ -673,7 +682,6 @@ public class CinderLoE {
         legsJade = (new LOTRItemArmor(MATERIAL_JADE, 2,"leggings")).setUnlocalizedName("lotr:legsJade").setTextureName("lotr:legsJade").setCreativeTab(null);
         bootsJade = (new LOTRItemArmor(MATERIAL_JADE, 3)).setUnlocalizedName("lotr:bootsJade").setTextureName("lotr:bootsJade").setCreativeTab(null);
 
-
         ItemRegistration.registerItem(frostblade, "frostblade", 30);
         ItemRegistration.registerItem(daggervoid, "daggerVoid", 96);
         ItemRegistration.registerItem(spearsolidgold, "spearsolidgold", 31);
@@ -690,6 +698,12 @@ public class CinderLoE {
         linkLOTRWeapon(spearUnnamed, "spearUnnamed");
         linkLOTRWeapon(whip, "whip");
 
+        // Common Tools/Weapons
+        cleaver = (new LOTRItemDagger(GONDOR)).setUnlocalizedName("lotr:cleaver").setTextureName("lotr:cleaver");
+
+        ItemRegistration.registerItem(cleaver,"cleaver",127);
+        linkLOTRWeapon(cleaver, "cleaver");
+
         //ASH
         MATERIAL_ASH = getLOTRMaterialByName("ASH");
         ingotAsh = new Item().setUnlocalizedName("lotr:ingotAsh").setTextureName("lotr:ingotAsh").setCreativeTab((CreativeTabs) materials);
@@ -1131,7 +1145,7 @@ public class CinderLoE {
         CinderCore.registerItemFallback(Block.getIdFromBlock(reedBale), Block.getIdFromBlock(Blocks.hay_block), "cinder_loe", "1.0");
         CinderCore.registerItemFallback(Block.getIdFromBlock(dwarvenBrickRuned), Block.getIdFromBlock(LOTRMod.brick), "cinder_loe", "1.0");
         CinderCore.registerItemFallback(Block.getIdFromBlock(fishBarrel), Block.getIdFromBlock(LOTRMod.woodBeam1), "cinder_loe", "1.1");
-        CinderCore.registerItemFallback(Block.getIdFromBlock(rustedsword), Block.getIdFromBlock(Blocks.nether_brick_fence), "cinder_loe", "1.2.5");
+        //CinderCore.registerItemFallback(Block.getIdFromBlock(rustedsword), Block.getIdFromBlock(Blocks.nether_brick_fence), "cinder_loe", "1.2.5");
         CinderCore.registerItemFallback(Block.getIdFromBlock(silverChain), Block.getIdFromBlock(LOTRMod.orcChain), "cinder_loe", "1.1");
         CinderCore.registerItemFallback(Block.getIdFromBlock(goldChain), Block.getIdFromBlock(LOTRMod.orcChain), "cinder_loe", "1.1");
         CinderCore.registerItemFallback(Block.getIdFromBlock(ironChain), Block.getIdFromBlock(LOTRMod.orcChain), "cinder_loe", "1.1");
@@ -1142,6 +1156,7 @@ public class CinderLoE {
         CinderCore.registerItemFallback(Block.getIdFromBlock(reeflessCoral), Block.getIdFromBlock(LOTRMod.coralReef), "cinder_loe", "1.2");
         CinderCore.registerItemFallback(Block.getIdFromBlock(plaster), Block.getIdFromBlock(Blocks.brick_block), "cinder_loe", "1.2.1");
         CinderCore.registerItemFallback(Block.getIdFromBlock(voidblock), Block.getIdFromBlock(Blocks.coal_block), "cinder_loe", "1.2.1");
+        CinderCore.registerItemFallback(Block.getIdFromBlock(mordorcobble),Block.getIdFromBlock(LOTRMod.brick),"cinder_loe", "1.2.5");
        // CinderCore.registerItemFallback(Block.getIdFromBlock(verticalWeaponRack), Block.getIdFromBlock(Blocks.fence), "cinder_loe", "1.2.4");
         // == Gates ==
         //CinderCore.registerItemFallback(Block.getIdFromBlock(gatecharredportcullis), Block.getIdFromBlock(LOTRMod.gateWoodenCross), "cinder_loe", "1.2.5");
@@ -1196,6 +1211,8 @@ public class CinderLoE {
         CinderCore.registerItemFallback(Item.getIdFromItem(bodyJade), Item.getIdFromItem(LOTRMod.bodyMithril),"cinder_loe", "1.2.5");
         CinderCore.registerItemFallback(Item.getIdFromItem(legsJade), Item.getIdFromItem(LOTRMod.legsMithril),"cinder_loe", "1.2.5");
         CinderCore.registerItemFallback(Item.getIdFromItem(bootsJade), Item.getIdFromItem(LOTRMod.bootsMithril),"cinder_loe", "1.2.5");
+        // == Common Tools/weapons ==
+        CinderCore.registerItemFallback(Item.getIdFromItem(cleaver),Item.getIdFromItem(LOTRMod.daggerIron),"cinder_loe","1.2.5");
         // == Ash Forged ==
         CinderCore.registerItemFallback(Item.getIdFromItem(ingotAsh), Item.getIdFromItem(LOTRMod.galvorn), "cinder_loe", "1.2");
         CinderCore.registerItemFallback(Item.getIdFromItem(daggerAsh), Item.getIdFromItem(LOTRMod.daggerBlackUruk), "cinder_loe", "1.2");
@@ -585,7 +594,7 @@ public class CinderLoE {
         * Weapons will need to be linked
          */
-        // Last ID added: 126
+        // Last ID added: 127
 
         // ==Food Items==
diff --git a/src/main/resources/assets/lotr/textures/blocks/mordorcobble.png b/src/main/resources/assets/lotr/textures/blocks/mordorcobble.png
new file mode 100644
index 0000000..267f73a
Binary files /dev/null and b/src/main/resources/assets/lotr/textures/blocks/mordorcobble.png differ
diff --git a/src/main/resources/assets/lotr/textures/blocks/onion_0.png b/src/main/resources/assets/lotr/textures/blocks/onion_0.png
index 7d3485f..f481537 100644
Binary files a/src/main/resources/assets/lotr/textures/blocks/onion_0.png and b/src/main/resources/assets/lotr/textures/blocks/onion_0.png differ
diff --git a/src/main/resources/assets/lotr/textures/blocks/onion_1.png b/src/main/resources/assets/lotr/textures/blocks/onion_1.png
index d015c29..50fd652 100644
Binary files a/src/main/resources/assets/lotr/textures/blocks/onion_1.png and b/src/main/resources/assets/lotr/textures/blocks/onion_1.png differ
diff --git a/src/main/resources/assets/lotr/textures/blocks/onion_2.png b/src/main/resources/assets/lotr/textures/blocks/onion_2.png
index 8ba1d8e..1b55755 100644
Binary files a/src/main/resources/assets/lotr/textures/blocks/onion_2.png and b/src/main/resources/assets/lotr/textures/blocks/onion_2.png differ
diff --git a/src/main/resources/assets/lotr/textures/blocks/onion_3.png b/src/main/resources/assets/lotr/textures/blocks/onion_3.png
index 9d4b0fc..ae35c2d 100644
Binary files a/src/main/resources/assets/lotr/textures/blocks/onion_3.png and b/src/main/resources/assets/lotr/textures/blocks/onion_3.png differ
